#
# spec file for package libbfio
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libbfio
%define lname	libbfio1
Version:        20221025
Release:        2.8
Summary:        Library to provide basic file input/output abstraction
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libbfio
Source:         https://github.com/libyal/libbfio/releases/download/%version/libbfio-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libbfio/releases/download/%version/libbfio-alpha-%version.tar.gz.asc
Source9:        %name.keyring
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcdata) >= 20220115
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20220107
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libuna) >= 20220611
# Various notes: https://en.opensuse.org/libyal

%description
libbfio is used in multiple other libraries like libewf, libmsiecf,
libnk2, libolecf and libpff. It is used to chain I/O to support
file-in-file access.

%package -n %lname
Summary:        Library to provide basic file input/output abstraction
Group:          System/Libraries

%description -n %lname
libbfio is used in multiple other libraries like libewf, libmsiecf,
libnk2, libolecf and libpff. It is used to chain I/O to support
file-in-file access.

%package devel
Summary:        Development files for libbfio, a basic file input/output abstraction library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libbfio is used in multiple other libraries like libewf, libmsiecf,
libnk2, libolecf and libpff. It is used to chain I/O to support
file-in-file access.

This subpackage contains libraries and header files for developing
applications that want to make use of libbfio.

%prep
%autosetup -p1

%build
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--disable-multi-thread LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log && exit 1
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libbfio.so.1*

%files devel
%_includedir/libbfio*
%_libdir/libbfio.so
%_libdir/pkgconfig/libbfio.pc
%_mandir/man3/libbfio.3*

%changelog
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Tue Oct 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221025
  * Changes to build infrastructure only
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220120
  * Unspecified updates
* Tue Jan 11 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220111
  * Additional name length checks
* Mon Jul  5 2021 Jan Engelhardt <jengelh@inai.de>
- Disable implicit library-side locking during operations;
  performance for e.g. libpff improves by another 22%%.
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210416 (3516e2a7f4)
  * No changelog was provided
- Add system-libs.patch
* Sat Dec 12 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201127
  * Changes to memory range IO handle
  * Worked on API functions
  * Worked on pool
* Tue May 12 2020 Paolo Stivanin <info@paolostivanin.com>
- update to v0~20200409 (no changelog)
* Tue Apr  2 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190112
  * Additional restrictions for memory tests
  * Changes for latest version of libcdata
* Wed Feb 15 2017 Greg.Freemyer@gmail.com
- update to v0~20170123
  * no changelog provided
- use libcstring from factory
* Fri Jan 29 2016 Greg.Freemyer@gmail.com
- update to v0~20160108
  * changes to seek
  * added function to remove handle from pool
  * 2016 update
  * merged history from backups
  * updated m4 scripts and msvscpp files
  * update man page: libbfio.3
* Tue Jan  6 2015 Greg.Freemyer@gmail.com
- update to v0~20150101
  * 2015 update - minimal changes
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcerror from OBS, not internal version
- continue to use internal version of libcstring
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- update to v0~20140105
  * 2014 update
  * updated dependencies
* Wed Oct 23 2013 Greg.Freemyer@gmail.com
- update to v0~20131003
* Thu Oct  3 2013 Greg.Freemyer@gmail.com
- update to v0~20130908
  * worked on tests
  * updated dependencies
- updated dependencies in specfile
* Mon Jul 29 2013 Greg.Freemyer@gmail.com
- update to v0~20130721
  * worked on multi threading support
  * removed open on demand code from seek offset
  * refactored pool to use a cdata array
  * worked on tests
  * updated dependencies
  * fix for compiling with stand-alone version of libcdata
  * fix in .pc.in file
  * worked on git release
  * moved examples to project page
  * removed codegear files
  * remove libbfio_legacy.[ch]
  * 2013 update
- change to gz compression to simplyfy download/convert step
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- run spec-cleaner, update comment
* Wed Apr  3 2013 jengelh@inai.de
- Initial package (version 0~20121225) for build.opensuse.org
